@@ -5,7 +5,6 @@ import builtins
 import copy
 import functools
 import inspect
-import platform
 import sys
 import uuid
 from typing import (Any, Mapping, Dict, List, Optional, Union, Tuple, Set, Callable, cast, Iterable, TypeVar)  # pylint: disable=unused-import
@@ -163,11 +162,11 @@ def _translate_all_expression_to_a_module(generator_exp: ast.GeneratorExp, gener
 
     args = [ast.arg(arg=name, annotation=None) for name in sorted(name_to_value.keys())]
 
-    if platform.python_version_tuple() < ('3', '5'):
-        raise NotImplementedError("Python versions below 3.5 not supported, got: {}".format(platform.python_version()))
+    if sys.version_info < (3, 5):
+        raise NotImplementedError("Python versions below 3.5 not supported, got: {}".format(sys.version_info))
 
     if not is_async:
-        if platform.python_version_tuple() < ('3', '8'):
+        if sys.version_info < (3, 8):
             func_def_node = ast.FunctionDef(
                 name=generated_function_name,
                 args=ast.arguments(args=args, kwonlyargs=[], kw_defaults=[], defaults=[], vararg=None, kwarg=None),
@@ -185,23 +184,23 @@ def _translate_all_expression_to_a_module(generator_exp: ast.GeneratorExp, gener
 
             module_node = ast.Module(body=[func_def_node], type_ignores=[])
     else:
-        if platform.python_version_tuple() < ('3', '8'):
-            func_def_node = ast.AsyncFunctionDef(
+        if sys.version_info < (3, 8):
+            async_func_def_node = ast.AsyncFunctionDef(
                 name=generated_function_name,
                 args=ast.arguments(args=args, kwonlyargs=[], kw_defaults=[], defaults=[], vararg=None, kwarg=None),
                 decorator_list=[],
                 body=block)
 
-            module_node = ast.Module(body=[func_def_node])
+            module_node = ast.Module(body=[async_func_def_node])
         else:
-            func_def_node = ast.AsyncFunctionDef(
+            async_func_def_node = ast.AsyncFunctionDef(
                 name=generated_function_name,
                 args=ast.arguments(
                     args=args, posonlyargs=[], kwonlyargs=[], kw_defaults=[], defaults=[], vararg=None, kwarg=None),
                 decorator_list=[],
                 body=block)
 
-            module_node = ast.Module(body=[func_def_node], type_ignores=[])
+            module_node = ast.Module(body=[async_func_def_node], type_ignores=[])
 
     ast.fix_missing_locations(module_node)
 
@@ -335,7 +334,7 @@ class Visitor(ast.NodeVisitor):
         recomputed_elts = [self.visit(node=elt) for elt in node.elts]
 
         # Please see "NOTE ABOUT PLACEHOLDERS AND RE-COMPUTATION"
-        if PLACEHOLDER in recomputed_elts:
+        if any(recomputed_elt is PLACEHOLDER for recomputed_elt in recomputed_elts):
             return PLACEHOLDER
 
         self.recomputed_values[node] = recomputed_elts
@@ -348,7 +347,7 @@ class Visitor(ast.NodeVisitor):
 
         recomputed_elts = tuple(self.visit(node=elt) for elt in node.elts)
         # Please see "NOTE ABOUT PLACEHOLDERS AND RE-COMPUTATION"
-        if PLACEHOLDER in recomputed_elts:
+        if any(recomputed_elt is PLACEHOLDER for recomputed_elt in recomputed_elts):
             return PLACEHOLDER
 
         self.recomputed_values[node] = recomputed_elts
@@ -358,7 +357,7 @@ class Visitor(ast.NodeVisitor):
         """Visit the elements and assemble the results into a set."""
         recomputed_elts = set(self.visit(node=elt) for elt in node.elts)
         # Please see "NOTE ABOUT PLACEHOLDERS AND RE-COMPUTATION"
-        if PLACEHOLDER in recomputed_elts:
+        if any(recomputed_elt is PLACEHOLDER for recomputed_elt in recomputed_elts):
             return PLACEHOLDER
 
         self.recomputed_values[node] = recomputed_elts
@@ -374,7 +373,7 @@ class Visitor(ast.NodeVisitor):
             recomputed_dict[self.visit(node=key)] = self.visit(node=val)
 
         # Please see "NOTE ABOUT PLACEHOLDERS AND RE-COMPUTATION"
-        if PLACEHOLDER in recomputed_dict or PLACEHOLDER in recomputed_dict.values():
+        if any(key is PLACEHOLDER or value is PLACEHOLDER for key, value in recomputed_dict.items()):
             return PLACEHOLDER
 
         self.recomputed_values[node] = recomputed_dict
@@ -441,7 +440,7 @@ class Visitor(ast.NodeVisitor):
         right = self.visit(node=node.right)
 
         # Please see "NOTE ABOUT PLACEHOLDERS AND RE-COMPUTATION"
-        if left == PLACEHOLDER or right == PLACEHOLDER:
+        if left is PLACEHOLDER or right is PLACEHOLDER:
             return PLACEHOLDER
 
         if isinstance(node.op, ast.Add):
@@ -481,7 +480,7 @@ class Visitor(ast.NodeVisitor):
         values = [self.visit(value_node) for value_node in node.values]
 
         # Please see "NOTE ABOUT PLACEHOLDERS AND RE-COMPUTATION"
-        if PLACEHOLDER in values:
+        if any(value is PLACEHOLDER for value in values):
             return PLACEHOLDER
 
         if isinstance(node.op, ast.And):
@@ -501,7 +500,7 @@ class Visitor(ast.NodeVisitor):
         comparators = [self.visit(node=comparator) for comparator in node.comparators]
 
         # Please see "NOTE ABOUT PLACEHOLDERS AND RE-COMPUTATION"
-        if left is PLACEHOLDER or PLACEHOLDER in comparators:
+        if left is PLACEHOLDER or any(comparator is PLACEHOLDER for comparator in comparators):
             return PLACEHOLDER
 
         result = None  # type: Optional[Any]
@@ -544,7 +543,7 @@ class Visitor(ast.NodeVisitor):
         func = self.visit(node=node.func)
 
         # Please see "NOTE ABOUT PLACEHOLDERS AND RE-COMPUTATION"
-        if func == PLACEHOLDER:
+        if func is PLACEHOLDER:
             return PLACEHOLDER
 
         if not callable(func):
@@ -587,7 +586,8 @@ class Visitor(ast.NodeVisitor):
                     kwargs[keyword.arg] = self.visit(node=keyword.value)
 
             # Please see "NOTE ABOUT PLACEHOLDERS AND RE-COMPUTATION"
-            if PLACEHOLDER in args or PLACEHOLDER in kwargs or PLACEHOLDER in kwargs.values():
+            if (any(arg is PLACEHOLDER for arg in args)
+                    or any(key is PLACEHOLDER or value is PLACEHOLDER for key, value in kwargs.items())):
                 return PLACEHOLDER
 
             result = func(*args, **kwargs)
@@ -663,16 +663,18 @@ class Visitor(ast.NodeVisitor):
 
             return value
 
-    def visit_Index(self, node: ast.Index) -> Any:
-        """Visit the node's ``value``."""
-        result = self.visit(node=node.value)
+    if sys.version_info < (3, 9):
 
-        # Please see "NOTE ABOUT PLACEHOLDERS AND RE-COMPUTATION"
-        if result is PLACEHOLDER:
-            return PLACEHOLDER
+        def visit_Index(self, node: ast.Index) -> Any:
+            """Visit the node's ``value``."""
+            result = self.visit(node=node.value)
 
-        self.recomputed_values[node] = result
-        return result
+            # Please see "NOTE ABOUT PLACEHOLDERS AND RE-COMPUTATION"
+            if result is PLACEHOLDER:
+                return PLACEHOLDER
+
+            self.recomputed_values[node] = result
+            return result
 
     def visit_Slice(self, node: ast.Slice) -> Union[slice, Placeholder]:
         """Visit ``lower``, ``upper`` and ``step`` and recompute the node as a ``slice``."""
@@ -697,15 +699,17 @@ class Visitor(ast.NodeVisitor):
         self.recomputed_values[node] = result
         return result
 
-    def visit_ExtSlice(self, node: ast.ExtSlice) -> Union[Tuple[Any, ...], Placeholder]:
-        """Visit each dimension of the advanced slicing and assemble the dimensions in a tuple."""
-        result = tuple(self.visit(node=dim) for dim in node.dims)
+    if sys.version_info < (3, 9):
 
-        if PLACEHOLDER in result:
-            return PLACEHOLDER
+        def visit_ExtSlice(self, node: ast.ExtSlice) -> Union[Tuple[Any, ...], Placeholder]:
+            """Visit each dimension of the advanced slicing and assemble the dimensions in a tuple."""
+            result = tuple(self.visit(node=dim) for dim in node.dims)
 
-        self.recomputed_values[node] = result
-        return result
+            if any(value is PLACEHOLDER for value in result):
+                return PLACEHOLDER
+
+            self.recomputed_values[node] = result
+            return result
 
     def visit_Subscript(self, node: ast.Subscript) -> Any:
         """Visit the ``slice`` and a ``value`` and get the element."""
@@ -717,7 +721,6 @@ class Visitor(ast.NodeVisitor):
             return PLACEHOLDER
 
         result = value[a_slice]
-
         self.recomputed_values[node] = result
         return result
 
@@ -775,16 +778,15 @@ class Visitor(ast.NodeVisitor):
     def _execute_comprehension(self, node: Union[ast.ListComp, ast.SetComp, ast.GeneratorExp, ast.DictComp]) -> Any:
         """Compile the generator or comprehension from the node and execute the compiled code."""
         # Please see "NOTE ABOUT NAME 🠒 VALUE STACKING".
-        if PLACEHOLDER in self._name_to_value.values():
+        if any(value is PLACEHOLDER for value in self._name_to_value.values()):
             return PLACEHOLDER
 
         args = [ast.arg(arg=name, annotation=None) for name in sorted(self._name_to_value.keys())]
 
-        if platform.python_version_tuple() < ('3', ):
-            raise NotImplementedError("Python versions below 3 not supported, got: {}".format(
-                platform.python_version()))
+        if sys.version_info < (3, ):
+            raise NotImplementedError("Python versions below 3 not supported, got: {}".format(sys.version_info))
 
-        if platform.python_version_tuple() < ('3', '8'):
+        if sys.version_info < (3, 8):
             func_def_node = ast.FunctionDef(
                 name="generator_expr",
                 args=ast.arguments(args=args, kwonlyargs=[], kw_defaults=[], defaults=[]),
